
//Licensed Materials - Property of IBM 
// Copyright IBM Corporation 2006, 2008. All Rights Reserved.

package com.telelogic.rhapsody.core;


 /**
  * The IRPAnnotation interface represents the different types of annotations you can add to your model - notes, comments, constraints, and requirements.
  */
public interface IRPAnnotation  extends IRPModelElement {
	/**
 	 * Adds an anchor from the annotation to the specified model element.
 	 * @param target the model element the annotation should be anchored to
 	 */
	public void addAnchor(IRPModelElement target);
	/**
 	 * Gets the list of model elements that are anchored to the annotation.
 	 * @return the model elements that are anchored to the annotation.
 	 */
	public IRPCollection getAnchoredByMe();
	/**
 	 * Gets the text of the specification for the annotation.
 	 * @return the text of the specification for the annotation
 	 */
	public String getBody();
	/**
 	 * Gets the text of the specification for the annotation.
 	 * @return the text of the specification for the annotation
 	 */
	public String getSpecification();
	/**
	 * get property specification RTF
	 * @throws RhapsodyRuntimeException
	 */
	public String getSpecificationRTF();
	/**
	 * anchoredByMe	RPCollection	RO	The list of model elements that are anchored to the annotation
 	
 			  java.lang.String 	getSpecificationRTF()
 	          get property specification RTF
 	
 			  int 	isSpecificationRTF()
 	          determine if specification is in RTF format
 	
 			  void 	removeAnchor(IRPModelElement target)
 	          Remove an anchor
 	 
 	 void 	setSpecificationRTF(java.lang.String specificationRTF)
 	          set property specification RTF
 			  
	 * @throws RhapsodyRuntimeException
	 */
	public int isSpecificationRTF();
	/**
	 * Remove an anchor
	 * @throws RhapsodyRuntimeException
	 */
	public void removeAnchor(IRPModelElement target);
	/**
 	 * Adds a specification to the annotation.
 	 * @param body the text to use as the specification
 	 */
	public void setBody(String body);
	/**
 	 * Adds a specification to the annotation.
 	 * @param specification the text to use as the specification
 	 */
	public void setSpecification(String specification);
	/**
	 * set property specification RTF
	 * @throws RhapsodyRuntimeException
	 */
	public void setSpecificationRTF(String specificationRTF);
}

