
//Licensed Materials - Property of IBM 
// Copyright IBM Corporation 2006, 2008. All Rights Reserved.

package com.telelogic.rhapsody.core;


 /**
  * Represents the features shared by elements such as classes, actors, use cases, and types.
  */
public interface IRPClassifier  extends IRPUnit {
	/**
	 * method addActivityDiagram
	 * @throws RhapsodyRuntimeException
	 */
	public IRPFlowchart addActivityDiagram();
	/**
	 * method addAttribute
	 * @throws RhapsodyRuntimeException
	 */
	public IRPAttribute addAttribute(String name);
	/**
	 * method addFlowItems
	 * @throws RhapsodyRuntimeException
	 */
	public IRPFlowItem addFlowItems(String name);
	/**
	 * method addFlows
	 * @throws RhapsodyRuntimeException
	 */
	public IRPFlow addFlows(String name);
	/**
	 * method addGeneralization
	 * @throws RhapsodyRuntimeException
	 */
	public void addGeneralization(IRPClassifier pVal);
	/**
	 * method addOperation
	 * @throws RhapsodyRuntimeException
	 */
	public IRPOperation addOperation(String name);
	/**
	 * method addRelation
	 * @throws RhapsodyRuntimeException
	 */
	public IRPRelation addRelation(String otherClassName, String otherClassPackageName, String roleName1, String linkType1, String multiplicity1, String roleName2, String linkType2, String multiplicity2, String linkName);
	/**
	 * method addRelationTo
	 * @throws RhapsodyRuntimeException
	 */
	public IRPRelation addRelationTo(IRPClassifier otherClassifier, String roleName1, String linkType1, String multiplicity1, String roleName2, String linkType2, String multiplicity2, String linkName);
	/**
	 * method addStatechart
	 * @throws RhapsodyRuntimeException
	 */
	public IRPStatechart addStatechart();
	/**
	 * method addUnidirectionalRelation
	 * @throws RhapsodyRuntimeException
	 */
	public IRPRelation addUnidirectionalRelation(String otherClassName, String otherClassPackageName, String roleName, String linkType, String multiplicity, String linkName);
	/**
	 * method addUnidirectionalRelationTo
	 * @throws RhapsodyRuntimeException
	 */
	public IRPRelation addUnidirectionalRelationTo(IRPClassifier otherClassifier, String roleName, String linkType, String multiplicity, String linkName);
	/**
	 * method deleteAttribute
	 * @throws RhapsodyRuntimeException
	 */
	public void deleteAttribute(IRPAttribute attribute);
	/**
	 * method deleteFlowItems
	 * @throws RhapsodyRuntimeException
	 */
	public void deleteFlowItems(IRPFlowItem pItem);
	/**
	 * method deleteFlows
	 * @throws RhapsodyRuntimeException
	 */
	public void deleteFlows(IRPFlow pFlow);
	/**
	 * method deleteGeneralization
	 * @throws RhapsodyRuntimeException
	 */
	public void deleteGeneralization(IRPClassifier superClass);
	/**
	 * method deleteOperation
	 * @throws RhapsodyRuntimeException
	 */
	public void deleteOperation(IRPOperation operation);
	/**
	 * method deleteRelation
	 * @throws RhapsodyRuntimeException
	 */
	public void deleteRelation(IRPRelation relation);
	/**
	 * method findAttribute
	 * @throws RhapsodyRuntimeException
	 */
	public IRPAttribute findAttribute(String newVal);
	/**
	 * method findBaseClassifier
	 * @throws RhapsodyRuntimeException
	 */
	public IRPClassifier findBaseClassifier(String newVal);
	/**
	 * method findDerivedClassifier
	 * @throws RhapsodyRuntimeException
	 */
	public IRPClassifier findDerivedClassifier(String newVal);
	/**
	 * method findGeneralization
	 * @throws RhapsodyRuntimeException
	 */
	public IRPGeneralization findGeneralization(String newVal);
	/**
 	 * Gets the operation or event reception that matches the signature provided.
 	 * @param signature the signature of the operation or event reception. The string you provide should consist of the operation name followed by parentheses containing a comma-delimited list of the types of the parameters, for example, "runEngine(int,int)".
 	 * @return the operation or event reception
 	 */
	public IRPInterfaceItem findInterfaceItem(String signature);
	/**
	 * method findNestedClassifier
	 * @throws RhapsodyRuntimeException
	 */
	public IRPClassifier findNestedClassifier(String newVal);
	/**
	 * method findNestedClassifierRecursive
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement findNestedClassifierRecursive(String newVal);
	/**
	 * method findRelation
	 * @throws RhapsodyRuntimeException
	 */
	public IRPRelation findRelation(String newVal);
	/**
	 * method findTrigger
	 * @throws RhapsodyRuntimeException
	 */
	public IRPInterfaceItem findTrigger(String name);
	/**
	 * get property activityDiagram
	 * @throws RhapsodyRuntimeException
	 */
	public IRPFlowchart getActivityDiagram();
	/**
	 * get property attributes
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getAttributes();
	/**
	 * method getAttributesIncludingBases
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getAttributesIncludingBases();
	/**
	 * get property baseClassifiers
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getBaseClassifiers();
	/**
	 * get property behavioralDiagrams
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getBehavioralDiagrams();
	/**
	 * get property derivedClassifiers
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getDerivedClassifiers();
	/**
	 * get property flowItems
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getFlowItems();
	/**
	 * get property flows
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getFlows();
	/**
	 * get property generalizations
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getGeneralizations();
	/**
	 * get property interfaceItems
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getInterfaceItems();
	/**
	 * method getInterfaceItemsIncludingBases
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getInterfaceItemsIncludingBases();
	/**
	 * get property links
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getLinks();
	/**
	 * get property nestedClassifiers
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getNestedClassifiers();
	/**
	 * get property operations
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getOperations();
	/**
	 * get property ports
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getPorts();
	/**
	 * get property relations
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getRelations();
	/**
	 * method getRelationsIncludingBases
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getRelationsIncludingBases();
	/**
	 * get property sequenceDiagrams
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getSequenceDiagrams();
	/**
 	 * Gets the source artifacts for the classifier.
 	 * @return the source artifacts for the classifier, as a collection of IRPFile objects
 	 */
	public IRPCollection getSourceArtifacts();
	/**
	 * get property statechart
	 * @throws RhapsodyRuntimeException
	 */
	public IRPStatechart getStatechart();
}

