
//Licensed Materials - Property of IBM 
// Copyright IBM Corporation 2006, 2008. All Rights Reserved.

package com.telelogic.rhapsody.core;


 /**
  * The IRPUnit interface represents model elements saved as units.
  */
public interface IRPUnit  extends IRPModelElement {
	/**
	 * get property CMHeader
	 * @throws RhapsodyRuntimeException
	 */
	public String getCMHeader();
	/**
 	 * Gets the name of the directory that contains the file used to store the unit. The string returned consists of the full path except for the name of the file itself.
 	 * @return the name of the directory that contains the file used to store the unit
 	 */
	public String getCurrentDirectory();
	/**
 	 * Gets the name of the file used to store the unit. The string returned consists only of the filename, not the entire path.
 	 * @return the name of the file used to store the unit
 	 */
	public String getFilename();
	/**
 	 * Checks whether the unit is going to be loaded the next time the model is loaded.
 	 * @return 1 if the unit is going to be loaded the next time the model is loaded, 0 if the unit is not going to be loaded
 	 */
	public int getIncludeInNextLoad();
	/**
 	 * Checks whether the unit is currently unloaded.
 	 * @return 1 if the unit is not currently loaded, 0 if it is currently loaded
 	 */
	public int getIsStub();
	/**
 	 * Gets the language of the unit.
 	 * @return the language of the unit
 	 */
	public String getLanguage();
	/**
	 * method getLastModifiedTime
	 * @throws RhapsodyRuntimeException
	 */
	public String getLastModifiedTime();
	/**
	 * Get nested save units
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getNestedSaveUnits();
	/**
	 * Get number of nested save units
	 * @throws RhapsodyRuntimeException
	 */
	public int getNestedSaveUnitsCount();
	/**
	 * get property structureDiagrams
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getStructureDiagrams();
	/**
 	 * Checks whether the file used to store the unit is read-only.
 	 * @return 1 if the file is read-only, 0 if the file is not read-only
 	 */
	public int isReadOnly();
	/**
 	 * Checks whether the unit was added to the model as a reference.
 	 * @return 1 if the unit was added to the model as a reference, 0 if it was not added as a reference
 	 */
	public int isReferenceUnit();
	/**
	 * method isSeparateSaveUnit
	 * @throws RhapsodyRuntimeException
	 */
	public int isSeparateSaveUnit();
	/**
 	 * Loads the unit.
 	 * @param withSubs indication of whether the unit's subunits should be loaded as well (1 to load the subunits as well, 0 to load only the unit itself)
 	 * @return the unit that was loaded
 	 */
	public IRPUnit load(int withSubs);
	/**
 	 * Saves the unit.
 	 * @param withSubs indication of whether the unit's subunits should be saved as well (1 to save the subunits as well, 0 to save only the unit itself)
 	 */
	public void save(int withSubs);
	/**
	 * set property CMHeader
	 * @throws RhapsodyRuntimeException
	 */
	public void setCMHeader(String cMHeader);
	/**
	 * set property filename
	 * @throws RhapsodyRuntimeException
	 */
	public void setFilename(String filename);
	/**
 	 * Toggles whether the unit is going to be loaded the next time the model is loaded.
 	 * @param includeInNextLoad Use 1 to specify that the unit should be loaded the next time the model is loaded, 0 to specify that the unit should not be loaded
 	 */
	public void setIncludeInNextLoad(int includeInNextLoad);
	/**
	 * method setLanguage
	 * @throws RhapsodyRuntimeException
	 */
	public void setLanguage(String newLanguage, int recursive);
	/**
 	 * Toggles the read-only status of the file used to store the unit.
 	 * @param pVal Use 1 to change the file to read-only, 0 to change the file to read/write
 	 */
	public void setReadOnly(int pVal);
	/**
	 * method setSeparateSaveUnit
	 * @throws RhapsodyRuntimeException
	 */
	public void setSeparateSaveUnit(int pVal);
	/**
	 * method setUnitPath
	 * @throws RhapsodyRuntimeException
	 */
	public void setUnitPath(String newPath);
	/**
 	 * Unloads the unit.
 	 */
	public void unload();
}

